import requests


headers={'Content-Type': 'application/json'}


def anime_logo(name):
    API = f"https://api.sdbots.tk/anime-logo?name={name}"
    req = requests.get(API).url
    return(req)

def tiktok(url):
    API = f"https://api.sdbots.tk/tiktok?url={url}"
    req = requests.get(API).json()
    return(req)

def apod():
    API = "https://api.sdbots.tk/apod"
    req = requests.get(API).json()
    return(req)

def detect_lang(text):
    req = requests.get(f"https://api.sdbots.tk/detect?text={text}").json()
    return(req)

def write(text):
    body = {
        "text": f"{text}"
    }
    url = "https://api.sdbots.tk/write"
    req = requests.post(url=url, headers=headers, json=body).url
    return(req)

def chk(cc):
    API = f"https://api.sdbots.tk/chk?cc={cc}"
    req = requests.get(API).json()
    return(req)

def sk_checker(key):
    req = requests.get(f"https://api.sdbots.tk/sk?key={key}").json()
    return(req)

def lyrics(song):
    req = requests.get(f"https://api.sdbots.tk/lyrics?song={song}").json()
    return(req)

def ipinfo(ip):
    req = requests.get(f"https://api.sdbots.tk/ipinfo?ip={ip}").json()
    return(req)

def hirunews():
    req = requests.get("https://api.sdbots.tk/hirunews").json()
    return(req)

def logohq(text):
    req = requests.get(f"https://api.sdbots.tk/logohq?text={text}").url
    return(req)

def fakeinfo():
    req = requests.get("https://api.sdbots.tk/fakeinfo").json()
    return(req)


a = anime_logo("DamanthaJa")
print(a)


from .pysdbots import *

__version__ = "0.1.1"


__all__ = [
    "anime_logo",
    "tiktok",
    "apod",
    "detect_lang",
    "write",
    "chk",
    "sk_checker",
    "lyrics",
    "ipinfo",
    "hirunews",
    "logohq",
    "fakeinfo",
]




import setuptools

with open("README.md", encoding="utf8") as readme:
    long_description = readme.read()

setuptools.setup(
    name="pysdbots",
    packages=setuptools.find_packages(),
    version="0.1.1",
    license="MIT",
    description="A Project Made To Centralize Various APIs 📖 No Authorization Needed :)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="DamanthaJasinghe",
    author_email="damanthaja@gmail.com",
    url="https://github.com/damantha126/pysdbots",
    keywords=["sdbots", "python-pakage", "sd-api", "api", "damanthaja", "mritzme", "damantha126"],
    install_requires=["requests>=2.28.1"],
    project_urls={
        "Tracker": "https://github.com/damantha126/pysdbots/issues",
        "Community": "https://t.me/SDBOTs_inifinity",
        "Source": "https://github.com/damantha126/pysdbots",
        "Documentation": "https://docs.sdbots.tk",
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
)